@@ -21,34 +21,40 @@ class Dataset():
         self.end=end
         self.log=log
         
+        #raw data
         self.raw=False
         self.show_raw=None
         self.raw_datas={}  #list of each rawdata time point  
         if raw is not None:
             self.raw=True
             self.raw_path=dirname(raw)+"/"
+            if dirname(raw)=="":
+                self.raw_path=""
             self.raw_files=basename(raw)
 
-        self.segment=False
+        #Segmentation
         self.seg_datas={}  #list of each segmented time point 
-        self.lineage_file="lineage.txt"
+        self.segment_path=""
+        self.segment_files="curated_t{:03d}.inr.gz"
         if segment is not None:
-            self.segment=True
             self.segment_path=dirname(segment)+"/"
+            if dirname(segment)=="":
+                self.segment_path=""
             self.segment_files=basename(segment)
             if not isdir(self.segment_path):
                 os.mkdir(self.segment_path)
-            self.lineage_file=join(self.segment_path,self.lineage_file)
+        
+        #Lineage
+        self.lineage_file="lineage.txt"
+        self.lineage_file=join(self.segment_path,self.lineage_file)
 
-            if self.log:
-                self.temp_path="morpho_log"
-                self.temp_path=join(self.segment_path,self.temp_path)
-                if not isdir(self.temp_path):
-                    os.mkdir(self.temp_path)
 
-                self.log_text="" #Line to log
-                self.log_file=join(self.temp_path,"morpho_log.txt")
-                
+        #LOG 
+        self.log_text="" #Line to log
+        if self.log:
+            self.log_file=join(self.segment_path,"morpho_log.txt")
+    
+
 
         self.background=background #Background Color
             
@@ -80,6 +86,7 @@ class Dataset():
 
 
     def restart(self,command):  #Apply and Restart a Curation 
+        print("--> Done " +command)
         self.save_log(command)
         for t in self.times:
             self.save_seg(t)
@@ -114,7 +121,8 @@ class Dataset():
     def _getDataSize(self):
         sif=0
         for t in self.seg_datas:
-            sif+=self.seg_datas[t].nbytes
+            if self.seg_datas[t] is not None:
+                sif+=self.seg_datas[t].nbytes
         return sif
 
     def _setVolume(self,data,t):
@@ -146,7 +154,7 @@ class Dataset():
             self.seg_datas[t]=data
         self._setVolume(data,t)
         if self.log and isfile(join(self.segment_path,self.segment_files.format(t))):
-            copy(join(self.segment_path,self.segment_files.format(t)),join(self.temp_path,datetime.now().strftime("%Y-%m-%d-%H-%M-%S")+"_"+self.segment_files.format(t)))
+            copy(join(self.segment_path,self.segment_files.format(t)),join(self.segment_path,datetime.now().strftime("%Y-%m-%d-%H-%M-%S")+"_"+self.segment_files.format(t)))
         compressed=False
         if not os.path.isfile(join(self.segment_path,self.segment_files.format(t))) and os.path.isfile(join(self.segment_path,self.segment_files.format(t)+".gz")):
             compressed=True
@@ -164,7 +172,7 @@ class Dataset():
         self._setLast(t) #Define the time step as used
         if t not in self.seg_datas:
             self.seg_datas[t]=None
-            if self.segment and isfile(join(self.segment_path,self.segment_files.format(t))):
+            if isfile(join(self.segment_path,self.segment_files.format(t))):
                 self.seg_datas[t]=imread(join(self.segment_path,self.segment_files.format(t)))
         return self.seg_datas[t]
 
@@ -238,7 +246,7 @@ class Dataset():
             #Export in PKL
             if self.pkl_file is not None:
                 if self.log and isfile(self.pkl_file):
-                    copy(self.pkl_file,join(self.temp_path,datetime.now().strftime("%Y-%m-%d-%H-%M-%S")+"_"+basename(self.pkl_file)))
+                    copy(self.pkl_file,join(self.segment_path,datetime.now().strftime("%Y-%m-%d-%H-%M-%S")+"_"+basename(self.pkl_file)))
                 lin_tree_information={}
                 for c in self.lineage_infos:
                     m=self.lineage_infos[c]
@@ -413,7 +421,7 @@ class Plot:#LOCAL SERVER TO COMMUNICATE DIRECTLY WITH UNITY
         print("---->>>  Uploading done")
 
     #Define a dataset 
-    def setDataset(self,begin,end,raw=None,segment=None,background=1,pkl_file=None,factor=4,raw_factor=4,memory=20):
+    def setDataset(self,begin=0,end=0,raw=None,segment=None,background=1,pkl_file=None,factor=4,raw_factor=4,memory=20):
         self.dataset=Dataset(begin,end,raw=raw,segment=segment,log=self.log,background=background,pkl_file=pkl_file,memory=memory)
         self.center=None
         self.factor=factor #Reduce factor to compute the obj
@@ -456,12 +464,13 @@ class Plot:#LOCAL SERVER TO COMMUNICATE DIRECTLY WITH UNITY
         self.unity_connection.stop() #Shut down the server
 
     def curate(self): #START UPLOAD AND WAIT FOR ANNOTATION
-        if self.dataset.segment:
-            if len(self.plugins)==0: #Initialise Default set of plugins
-                self.set_default_plugins()
+        if len(self.plugins)==0: #Initialise Default set of plugins
+            self.set_default_plugins()
+
         self.plot_meshes()
         self.plot_volumes()
         self.plot_lineage()
+
         self._annotate()
 
 
@@ -477,6 +486,8 @@ class Plot:#LOCAL SERVER TO COMMUNICATE DIRECTLY WITH UNITY
             global inter
             print(" Send rawdatas at "+str(t))
             rawdata=self.dataset.get_raw(t)
+            new_shape=np.uint16(np.floor(np.array(rawdata.shape)/self.raw_factor)*self.raw_factor) #To avoid shifting issue
+            rawdata=rawdata[0:new_shape[0],0:new_shape[1],0:new_shape[2]]
             factor_data=rawdata[::self.raw_factor,::self.raw_factor,::self.raw_factor]
             bdata=np.uint8(np.float32(np.iinfo(np.uint8).max)*factor_data/factor_data.max()).tobytes(order="F")        
             inter.wait()
@@ -516,10 +527,11 @@ class Plot:#LOCAL SERVER TO COMMUNICATE DIRECTLY WITH UNITY
         return Text
 
     def plot_infos(self,infoname,infos): #PLOT INFOR (CORRESPONDENCAE)
-        global inter
-        inter.wait() #Wait free request to plot
-        inter.obj=infos
-        inter.post("INFO_"+infoname.replace(" ","_"))
+        if len(infos.split('\n'))>4:
+            global inter
+            inter.wait() #Wait free request to plot
+            inter.obj=infos
+            inter.post("INFO_"+infoname.replace(" ","_"))
  
     def plot_lineage(self):
         if self.dataset.lineage:
@@ -536,7 +548,7 @@ class Plot:#LOCAL SERVER TO COMMUNICATE DIRECTLY WITH UNITY
         global inter
         inter.wait()
         inter.reset()  
-        inter.post("ANNOTATE")
+        inter.post("ANNOTATE_"+str(self.dataset.begin)+"_"+str(self.dataset.end))
 
 
     def _getCenterText(self):
@@ -545,8 +557,6 @@ class Plot:#LOCAL SERVER TO COMMUNICATE DIRECTLY WITH UNITY
         return "0_0_0"
 
     ##### MESH FUNCTIONS
-    
-
     def _get_mesh(self,t,data):
         from morphonet.tools import convertToOBJ
         if self.center is None:
@@ -556,13 +566,15 @@ class Plot:#LOCAL SERVER TO COMMUNICATE DIRECTLY WITH UNITY
     
     def plot_mesh(self,t): #UPLOAD DITECLTY THE OBJ TIME POINT IN UNITY
         global inter
-        if self.dataset.segment:
-            inter.wait()
-            print(" ->  Send mesh at "+str(t))
-            data=self.dataset.get_seg(t)
+        inter.wait()
+        data=self.dataset.get_seg(t)
+        print(" ->  Send mesh at "+str(t))
+        if data is not None:
             self.dataset._setVolume(data,t) #Update Volumes
             inter.obj=self._get_mesh(t,data)
-            inter.post("LOAD_"+str(t))
+        else:
+            inter.obj=""
+        inter.post("LOAD_"+str(t))
 
     def plotAt(self,t,obj):#PLOT DIRECTLY THE OBJ PASS IN ARGUMENT
         global inter
